"""Convenience exports for the AnytimeSeries Qt GUI components."""
from .utils import (
    ORCAFLEX_VARIABLE_MAP,
    MATH_FUNCTIONS,
    _find_xyz_triples,
    _safe,
    _looks_like_user_var,
    _parse_search_terms,
    _matches_terms,
    get_object_available_vars,
)
from .sortable_table_widget_item import SortableTableWidgetItem
from .variable_tab import VariableRowWidget, VariableTab
from .stats_dialog import StatsDialog
from .evm_window import EVMWindow
from .orcaflex_selector import OrcaflexVariableSelector
from .file_loader import FileLoader
from .editor import TimeSeriesEditorQt

__all__ = [
    'ORCAFLEX_VARIABLE_MAP',
    'MATH_FUNCTIONS',
    '_find_xyz_triples',
    '_safe',
    '_looks_like_user_var',
    '_parse_search_terms',
    '_matches_terms',
    'get_object_available_vars',
    'SortableTableWidgetItem',
    'VariableRowWidget',
    'VariableTab',
    'StatsDialog',
    'EVMWindow',
    'OrcaflexVariableSelector',
    'FileLoader',
    'TimeSeriesEditorQt',
]




"""ANYtimes public package interface."""

try:
    from . import anytimes_gui  # noqa: F401
    from .anytimes_gui import *  # noqa: F401,F403
except Exception:  # pragma: no cover - GUI dependencies are optional during tests
    anytimes_gui = None  # type: ignore[assignment]

from . import evm  # noqa: F401

__all__ = [name for name in globals() if not name.startswith('_')]
